@@ -2,6 +2,7 @@ from collections import namedtuple
 
 from .publish import publish_chains
 from .revert import revert_chains
+from .unpublish import unpublish_chains
 
 __all__ = ['generic']
 
@@ -29,11 +30,13 @@ Generic = namedtuple(
     'Generic',
     [
         'publish',
-        'revert'
+        'revert',
+        'unpublish'
     ])
 
 # Create an instance of Generic containing all the generic views
 generic = Generic(
     publish=publish_chains,
-    revert=revert_chains
+    revert=revert_chains,
+    unpublish=unpublish_chains,
 )
